==> ah-form-builder-sample-0.6.19.tgz: package/es/components/toolbar/field-forms/Signature.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/components/toolbar/field-forms/Signature.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import SimpleTabs from "../../../utils/Tabs/SimpleTabs";
import TextInput from "../../../utils/inputs/TextInput";
import Checkbox from "../../../utils/checkboxs/Checkbox";
import ValidateField from "../../../utils/validations/ValidateField";
import Button from "@material-ui/core/Button";
import { disableFieldEdit as _disableFieldEdit } from "../../../actions/toolbarActions";
import { createField as _createField, deleteField as _deleteField, deleteNewField as _deleteNewField, updateField as _updateField } from '../../../actions/formActions';
import { connect } from "react-redux";
import DateValidation from "../../../utils/date-validation";
import { InputLabel } from '@material-ui/core';
import RichTextEditor from '../../../utils/rich-text-editor';
import { Scrollbars } from 'react-custom-scrollbars';
import ConditionalLogic from '../../../utils/conditional-logic';
import SearchableSelect from '../../../utils/selects/SearchableSelect';
import { getHeight } from '../../../utils/helpers';

var Signature = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Signature, _React$Component);

  function Signature(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleTabChange", function (e, newValue) {
      _this.setState({
        activeTab: newValue
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleDataChange", function (val, name) {
      var _this$setState;

      _this.setState((_this$setState = {}, _this$setState[name] = val, _this$setState.errors = {}, _this$setState));
    });

    _defineProperty(_assertThisInitialized(_this), "saveField", function () {
      var _this$state = _this.state,
          name = _this$state.name,
          machineName = _this$state.machineName,
          order = _this$state.order,
          conditionalLogic = _this$state.conditionalLogic,
          isRequired = _this$state.isRequired,
          helpText = _this$state.helpText,
          subType = _this$state.subType,
          visibility = _this$state.visibility,
          uuid = _this$state.uuid,
          type = _this$state.type,
          parentId = _this$state.parentId;
      var newField = {
        name: name,
        machineName: machineName,
        order: order,
        uuid: uuid,
        type: type,
        parentId: parentId,
        config: {
          conditionalLogic: conditionalLogic,
          isRequired: isRequired,
          helpText: helpText,
          subType: subType,
          visibility: visibility
        }
      };
      ValidateField(newField).then(function () {
        _this.props.updateField(newField);

        _this.props.disableFieldEdit();
      })["catch"](function (errors) {
        var keys = Object.keys(errors);

        if (keys[0] === 'machineName' || keys[0] === 'conditionalLogic') {
          _this.handleTabChange({}, 'advance');
        } else {
          _this.handleTabChange({}, 'basic');
        }

        _this.setState({
          errors: errors
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "cancelEdit", function () {
      _this.props.deleteNewField();

      _this.props.disableFieldEdit();
    });

    _defineProperty(_assertThisInitialized(_this), "renderTabFields", function () {
      if (_this.state.activeTab === 'basic') {
        return /*#__PURE__*/React.createElement("div", {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 76,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement(Checkbox, {
          checked: _this.state.isRequired,
          handleChange: function handleChange(val) {
            return _this.handleDataChange(val, 'isRequired');
          },
          label: "Required",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 77,
            columnNumber: 11
          }
        }), /*#__PURE__*/React.createElement("div", {
          className: "mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 78,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.name,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'name');
          },
          label: "Field Name",
          required: true,
          autoFocus: true,
          error: _this.state.errors.name,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 79,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement("div", {
          className: "mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 81,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.helpText,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'helpText');
          },
          label: "Help Text",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 82,
            columnNumber: 13
          }
        })));
      } else {
        return /*#__PURE__*/React.createElement("div", {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 88,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement("div", {
          className: "mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 89,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.machineName,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'machineName');
          },
          label: "Machine Name/Field ID",
          required: true,
          autoFocus: true,
          error: _this.state.errors.machineName,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 90,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement("div", {
          className: "mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 92,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(SearchableSelect, {
          options: [{
            label: 'Visible',
            value: 'visible'
          }, {
            label: 'Hidden',
            value: 'hidden'
          }],
          label: "Visibility to Employee",
          value: _this.state.visibility ? 'visible' : 'hidden',
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value === 'visible', 'visibility');
          },
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 93,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement(ConditionalLogic, {
          conditionalLogic: _this.state.conditionalLogic,
          isConditionalEnabled: _this.state.isConditionalEnabled,
          handleChange: _this.handleDataChange,
          errors: _this.state.errors.conditionalLogic ? _this.state.errors.conditionalLogic : [],
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 95,
            columnNumber: 11
          }
        }));
      }
    });

    _this.state = _extends({
      activeTab: 'basic',
      errors: {},
      uuid: props.data.uuid,
      name: props.data.name,
      type: props.data.type,
      order: props.data.order,
      parentId: props.data.parentId,
      machineName: props.data.machineName,
      isConditionalEnabled: !!props.data.config.conditionalLogic.length
    }, props.data.config);
    return _this;
  }

  var _proto = Signature.prototype;

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 103,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(SimpleTabs, {
      value: this.state.activeTab,
      handleChange: this.handleTabChange,
      options: [{
        label: 'Basic Settings',
        value: 'basic'
      }, {
        label: 'Advance Settings',
        value: 'advance'
      }],
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 104,
        columnNumber: 9
      }
    }), /*#__PURE__*/React.createElement(Scrollbars, {
      style: {
        height: getHeight(true, true)
      },
      autoHide: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 105,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "p-3 my-3",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 106,
        columnNumber: 11
      }
    }, this.renderTabFields(), /*#__PURE__*/React.createElement("div", {
      className: "width-full text-right",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 108,
        columnNumber: 13
      }
    }, /*#__PURE__*/React.createElement(Button, {
      variant: "outlined",
      color: "primary",
      className: "mr-2",
      onClick: this.cancelEdit,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 109,
        columnNumber: 15
      }
    }, "Cancel"), /*#__PURE__*/React.createElement(Button, {
      variant: "contained",
      color: "primary",
      disableElevation: true,
      onClick: this.saveField,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 112,
        columnNumber: 15
      }
    }, "Save")))));
  };

  return Signature;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    operation: state.toolbar.operation,
    predefined: state.form.predefined
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    deleteNewField: function deleteNewField() {
      return dispatch(_deleteNewField());
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    updateField: function updateField(data) {
      return dispatch(_updateField(data));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(Signature);

==> ah-form-builder-sample-0.6.82.tgz: package/es/components/toolbar/field-forms/Signature.js <==
var _jsxFileName = "/var/www/html/formbuilder/src/components/toolbar/field-forms/Signature.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import SimpleTabs from "../../../utils/Tabs/SimpleTabs";
import TextInput from "../../../utils/inputs/TextInput";
import ValidateField from "../../../utils/validations/ValidateField";
import Button from "@material-ui/core/Button";
import { disableFieldEdit as _disableFieldEdit } from "../../../actions/toolbarActions";
import { createField as _createField, deleteField as _deleteField, deleteNewField as _deleteNewField, updateField as _updateField } from '../../../actions/formActions';
import { connect } from "react-redux";
import { Scrollbars } from 'react-custom-scrollbars';
import ConditionalLogic from '../../../utils/conditional-logic';
import SearchableSelect from '../../../utils/selects/SearchableSelect';
import { getHeight } from '../../../utils/helpers';
import FieldRenderer from './utils/FieldRenderer';
import { eSignatureFieldsConfigs } from './utils/eSignatureFieldConfigs';
import { processLocalFields } from './utils/helpers';
var basicTabTitle = {
  en: 'Basic Settings',
  ar: 'الإعدادات الأساسية'
};
var advanceTabTitle = {
  en: 'Advance Settings',
  ar: 'إعدادات متقدمة'
};
var machineNameLabel = {
  en: 'Machine Name/Field ID',
  ar: 'إسم الألة'
};
var visibilityLabel = {
  en: 'Visibility to Employee',
  ar: 'الرؤية للموظف'
};
var cancelLabel = {
  en: 'Cancel',
  ar: 'إلغاء'
};
var saveLabel = {
  en: 'Save',
  ar: 'حفظ'
};
var visibleLabel = {
  en: 'Visible',
  ar: 'مرئي'
};
var hiddenLabel = {
  en: 'Hidden',
  ar: 'مختفي'
};

var Signature = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Signature, _React$Component);

  function Signature(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleTabChange", function (e, newValue) {
      _this.setState({
        activeTab: newValue
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleDataChange", function (val, name) {
      var _this$setState;

      _this.setState((_this$setState = {}, _this$setState[name] = val, _this$setState.errors = {}, _this$setState));
    });

    _defineProperty(_assertThisInitialized(_this), "saveField", function () {
      var _this$state = _this.state,
          name = _this$state.name,
          machineName = _this$state.machineName,
          order = _this$state.order,
          conditionalLogic = _this$state.conditionalLogic,
          isRequired = _this$state.isRequired,
          helpText = _this$state.helpText,
          subType = _this$state.subType,
          visibility = _this$state.visibility,
          uuid = _this$state.uuid,
          type = _this$state.type,
          parentId = _this$state.parentId;
      var newField = {
        name: name,
        machineName: machineName,
        order: order,
        uuid: uuid,
        type: type,
        parentId: parentId,
        config: {
          conditionalLogic: conditionalLogic,
          isConditionalEnabled: !!conditionalLogic.conditions.length,
          isRequired: isRequired,
          helpText: helpText,
          subType: subType,
          visibility: visibility
        }
      };
      newField.locals = processLocalFields(_this.props.locals, _this.state);
      ValidateField(newField).then(function () {
        _this.props.updateField(newField);

        _this.props.disableFieldEdit();
      })["catch"](function (errors) {
        var keys = Object.keys(errors);

        if (keys[0] === 'machineName' || keys[0] === 'conditionalLogic') {
          _this.handleTabChange({}, 'advance');
        } else {
          _this.handleTabChange({}, 'basic');
        }

        _this.setState({
          errors: errors
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "cancelEdit", function () {
      _this.props.deleteNewField();

      _this.props.disableFieldEdit();
    });

    _defineProperty(_assertThisInitialized(_this), "renderTabFields", function () {
      if (_this.state.activeTab === 'basic') {
        return /*#__PURE__*/React.createElement("div", {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 123,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement(FieldRenderer, _extends({}, _this.state, {
          locals: _this.props.locals,
          fieldConfigs: eSignatureFieldsConfigs,
          handleDataChange: _this.handleDataChange,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 124,
            columnNumber: 11
          }
        })));
      } else {
        return /*#__PURE__*/React.createElement("div", {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 141,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 142,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.machineName,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'machineName');
          },
          label: machineNameLabel[_this.props.currentLang],
          required: true,
          autoFocus: true,
          error: _this.state.errors.machineName,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 143,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 145,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(SearchableSelect, {
          options: [{
            label: visibleLabel[_this.props.currentLang],
            value: 'visible'
          }, {
            label: hiddenLabel[_this.props.currentLang],
            value: 'hidden'
          }],
          label: visibilityLabel[_this.props.currentLang],
          value: _this.state.visibility ? 'visible' : 'hidden',
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value === 'visible', 'visibility');
          },
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 146,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement(ConditionalLogic, {
          predefined: _this.props.predefined,
          conditionalLogic: _this.state.conditionalLogic,
          isConditionalEnabled: _this.state.isConditionalEnabled,
          handleChange: _this.handleDataChange,
          errors: _this.state.errors.conditionalLogic ? _this.state.errors.conditionalLogic : [],
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 148,
            columnNumber: 11
          }
        }));
      }
    });

    _this.state = _extends({
      activeTab: 'basic',
      errors: {},
      uuid: props.data.uuid,
      name: props.data.name,
      type: props.data.type,
      order: props.data.order,
      parentId: props.data.parentId,
      machineName: props.data.machineName
    }, props.data.config);
    return _this;
  }

  var _proto = Signature.prototype;

  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (nextProps.data.uuid !== this.state.uuid) {
      this.setState(_extends({
        activeTab: 'basic',
        errors: {},
        uuid: nextProps.data.uuid,
        name: nextProps.data.name,
        type: nextProps.data.type,
        order: nextProps.data.order,
        parentId: nextProps.data.parentId,
        machineName: nextProps.data.machineName
      }, nextProps.data.config));
    }
  };

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 156,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(SimpleTabs, {
      value: this.state.activeTab,
      handleChange: this.handleTabChange,
      options: [{
        label: basicTabTitle[this.props.currentLang],
        value: 'basic'
      }, {
        label: advanceTabTitle[this.props.currentLang],
        value: 'advance'
      }],
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 157,
        columnNumber: 9
      }
    }), /*#__PURE__*/React.createElement(Scrollbars, {
      style: {
        height: getHeight(true, true)
      },
      autoHide: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 158,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-p-3 ahfb-my-3",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 159,
        columnNumber: 11
      }
    }, this.renderTabFields(), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-width-full ahfb-text-right",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 161,
        columnNumber: 13
      }
    }, /*#__PURE__*/React.createElement(Button, {
      variant: "outlined",
      color: "primary",
      className: "ahfb-mr-2",
      onClick: this.cancelEdit,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 162,
        columnNumber: 15
      }
    }, cancelLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Button, {
      variant: "contained",
      color: "primary",
      disableElevation: true,
      onClick: this.saveField,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 165,
        columnNumber: 15
      }
    }, saveLabel[this.props.currentLang])))));
  };

  return Signature;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    operation: state.toolbar.operation,
    predefined: state.form.predefined,
    locals: state.form.locals,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    deleteNewField: function deleteNewField() {
      return dispatch(_deleteNewField());
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    updateField: function updateField(data) {
      return dispatch(_updateField(data));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(Signature);
